

import java.awt.*;
import java.awt.event.*;



class InputDialog extends Dialog
					implements ActionListener
{
	
	private TextField responseField;
	private String initialResponse;
	private boolean cancelled;
	
	
	public InputDialog(Frame owner, String message, String initialResponse)
	{
		super(owner, true);		// true -> modal dialog
		
		this.setLayout(new BorderLayout());
		this.add(new Label(message), BorderLayout.NORTH);
		
		responseField = new TextField(20);
		responseField.setText(initialResponse);
		this.add(responseField, BorderLayout.CENTER);
		
		Panel buttonPanel = new Panel();
		buttonPanel.setLayout(new BorderLayout());
		
		Button okButton = new Button("OK");
		okButton.setActionCommand("ok");
		okButton.addActionListener(this);
		buttonPanel.add(okButton, BorderLayout.WEST);
		
		Button cancelButton = new Button("Cancel");
		cancelButton.setActionCommand("cancel");
		cancelButton.addActionListener(this);
		buttonPanel.add(cancelButton, BorderLayout.EAST);
		
		this.add(buttonPanel, BorderLayout.SOUTH);
		
		this.initialResponse = initialResponse;
		this.cancelled = false;
	}
	
	
	
	public InputDialog(Frame owner, String message)
	{
		// just no initial response
		this(owner, message, "");
	}
	
	
	
	public void actionPerformed(ActionEvent theEvent)
	// respond to button pushes, menu selections
	{
		String command = theEvent.getActionCommand();
		
	
		if (command == "ok")
		{
			this.hide();
		}
		
		if (command == "cancel")
		{
			cancelled = true;
			this.hide();
		}
		
	}
	
	
	public static String getInputFromDialog(Frame owner, String message, String initialResponse)
	{
		InputDialog theDialog = new InputDialog(owner, message, initialResponse);
		theDialog.pack();
		theDialog.show();
		
		// show() will block until hide() is called in response to a click on the
		// OK or Cancel buttons
		
		String responseString;
		
		if (theDialog.cancelled)
			responseString = null;
		else
			responseString = theDialog.responseField.getText();
			
		theDialog.dispose();
		
		return responseString;
	}
}